From e05b61e912d25fc887dd025ed454feaa486af988 Mon Sep 17 00:00:00 2001
From: jerry <jerry@c27b2ed6-37b1-4487-878e-468635907f87>
Date: Fri, 6 May 2011 08:33:06 +0000
Subject: [PATCH] M arch/arm/mach-cns3xxx/Makefile.boot M
 arch/arm/mach-cns3xxx/Kconfig M
 arch/arm/mach-cns3xxx/include/mach/memory.h M
 arch/arm/mach-cns3xxx/cns3420vb.c M arch/arm/Kconfig

Source: Cavium, Inc
MR: 44907
Type: Integration
Disposition: Merged from Cavium SDK_VERSION 1.2-2482
ChangeID: 5d86ff11eddf8c954cb8e2b87f639b56a5b94ce6
Description:

Support 1Gbyte DDR2 SDRAM memory space.
1. PHYS_OFFSET => 0x20000000
2. PAGE_OFFSET => 0xA0000000

If board support more than 256MB of RAM, user must to enable this feature (CONFIG_CNS3XXX_HIGH_PHYS_OFFSET).
(CONFIG_CNS3XXX_HIGH_PHYS_OFFSET is enabled by default)

git-svn-id: svn://localhost/vega/trunk@2231 c27b2ed6-37b1-4487-878e-468635907f87

Signed-off-by: Randy Vinson <rvinson@mvista.com>
Signed-off-by: Dale Farnsworth <dfarnsworth@mvista.com>
---
 arch/arm/Kconfig                            |    1 +
 arch/arm/mach-cns3xxx/Kconfig               |   11 +++++++++++
 arch/arm/mach-cns3xxx/Makefile.boot         |    6 ++++++
 arch/arm/mach-cns3xxx/cns3420vb.c           |   17 ++++++++++++++++-
 arch/arm/mach-cns3xxx/include/mach/memory.h |    4 ++++
 5 files changed, 38 insertions(+), 1 deletion(-)

diff --git a/arch/arm/Kconfig b/arch/arm/Kconfig
index 4027169..a66e321 100644
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -1169,6 +1169,7 @@ config PAGE_OFFSET
 	hex
 	default 0x40000000 if VMSPLIT_1G
 	default 0x80000000 if VMSPLIT_2G
+	default 0xA0000000 if (ARCH_CNS3XXX && CNS3XXX_HIGH_PHYS_OFFSET)
 	default 0xC0000000
 
 config NR_CPUS
diff --git a/arch/arm/mach-cns3xxx/Kconfig b/arch/arm/mach-cns3xxx/Kconfig
index 446ec73..586a36d 100644
--- a/arch/arm/mach-cns3xxx/Kconfig
+++ b/arch/arm/mach-cns3xxx/Kconfig
@@ -60,4 +60,15 @@ endchoice
 config CNS3XXX_SPEEDUP_NAS
 	bool "NAS Speedup"
 
+config CNS3XXX_HIGH_PHYS_OFFSET
+    bool "High physical base address for the CNS3XXX platform"
+    depends on MMU
+    default y
+    help
+      CNS3XXX boards have the RAM available at 0x20000000, 
+      256MB of which being mirrored at 0x00000000. 
+      If the board supports 512MB of RAM, this option allows the 
+      memory to be accessed contiguously at the high physical
+      offset.
+
 endmenu
diff --git a/arch/arm/mach-cns3xxx/Makefile.boot b/arch/arm/mach-cns3xxx/Makefile.boot
index 7770128..6fc3356 100644
--- a/arch/arm/mach-cns3xxx/Makefile.boot
+++ b/arch/arm/mach-cns3xxx/Makefile.boot
@@ -1,3 +1,9 @@
+ifeq ($(CONFIG_CNS3XXX_HIGH_PHYS_OFFSET),y)
+   zreladdr-y	:= 0x20008000
+params_phys-y	:= 0x20000100
+initrd_phys-y	:= 0x20C00000
+else
    zreladdr-y	:= 0x00008000
 params_phys-y	:= 0x00000100
 initrd_phys-y	:= 0x00C00000
+endif
diff --git a/arch/arm/mach-cns3xxx/cns3420vb.c b/arch/arm/mach-cns3xxx/cns3420vb.c
index 0bc8163..c9a6c0c 100644
--- a/arch/arm/mach-cns3xxx/cns3420vb.c
+++ b/arch/arm/mach-cns3xxx/cns3420vb.c
@@ -525,6 +525,18 @@ static struct map_desc cns3420_io_desc[] __initdata = {
         },
 };
 
+#ifdef CONFIG_CNS3XXX_HIGH_PHYS_OFFSET
+static void __init cns3420_fixup(struct mach_desc *desc,
+				struct tag *tags, char **cmdline,
+				struct meminfo *mi)
+{
+	mi->nr_banks = 1;
+	mi->bank[0].start = PHYS_OFFSET;
+	mi->bank[0].size = SZ_512M;
+	mi->bank[0].node = 0;
+}
+#endif
+
 static void __init cns3420_map_io(void)
 {
 	cns3xxx_map_io();
@@ -536,7 +548,10 @@ static void __init cns3420_map_io(void)
 MACHINE_START(CNS3420VB, "Cavium Networks CNS3420 Validation Board")
 	.phys_io	= CNS3XXX_UART0_BASE,
 	.io_pg_offst	= (CNS3XXX_UART0_BASE_VIRT >> 18) & 0xfffc,
-	.boot_params	= 0x00000100,
+	.boot_params	= PHYS_OFFSET + 0x00000100,
+#ifdef CONFIG_CNS3XXX_HIGH_PHYS_OFFSET
+	.fixup		= cns3420_fixup,
+#endif
 	.map_io		= cns3420_map_io,
 	.init_irq	= cns3xxx_init_irq,
 	.timer		= &cns3xxx_timer,
diff --git a/arch/arm/mach-cns3xxx/include/mach/memory.h b/arch/arm/mach-cns3xxx/include/mach/memory.h
index 3b6b769..59b2778 100644
--- a/arch/arm/mach-cns3xxx/include/mach/memory.h
+++ b/arch/arm/mach-cns3xxx/include/mach/memory.h
@@ -13,7 +13,11 @@
 /*
  * Physical DRAM offset.
  */
+#ifdef CONFIG_CNS3XXX_HIGH_PHYS_OFFSET
+#define PHYS_OFFSET		UL(0x20000000)
+#else
 #define PHYS_OFFSET		UL(0x00000000)
+#endif
 
 #define __phys_to_bus(x)	((x) + PHYS_OFFSET)
 #define __bus_to_phys(x)	((x) - PHYS_OFFSET)
-- 
1.7.9.5

